@@ -9,7 +9,7 @@
  *
  * @Notes: Big text file tokenization and transformation
  *
- * @last-modified: October 2017
+ * @last-modified: March 2019
  *
  **/
 
@@ -518,19 +518,19 @@ class big_files {
             Rcpp::Rcout << "the split of the character string and simultaneously the removal of the punctuation in the vector starts ..." << std::endl;
           }
         }
-
+        
         t.TOKENIZER(cpp_string_separator, remove_punctuation_vector);
       }
-
+      
       if (cpp_remove_stopwords) {
-
+        
         if (verbose) { Rcpp::Rcout << "stop words of the " << language_spec << " language will be used" << std::endl; }
-
+        
         t.read_stopwords(language);
-
+        
         if (verbose) { Rcpp::Rcout << "the removal of stop-words starts ..." << std::endl; }
-
-        t.remove_stopwords(threads);}
+        
+        t.remove_stopwords(threads, remove_punctuation_vector);}
 
       if (min_num_char > 1 || max_num_char < 1000000000) {
 
